@@ -233,13 +233,31 @@ class IPPToolWrapper(object):
     @pyipptool_coroutine
     def create_job(self, uri,
                    printer_uri=None,
+                   job_name=colander.null,
+                   ipp_attribute_fidelity=colander.null,
+                   document_name=colander.null,
+                   compression=colander.null,
+                   document_format=colander.null,
+                   document_natural_language=colander.null,
+                   job_k_octets=colander.null,
+                   job_impressions=colander.null,
+                   job_media_sheets=colander.null,
                    auth_info=colander.null,
                    job_billing=colander.null,
                    job_sheets=colander.null,
                    media=colander.null):
         kw = {'header':
               {'operation_attributes':
-               {'printer_uri': printer_uri}},
+               {'printer_uri': printer_uri,
+                'job_name': job_name,
+                'ipp_attribute_fidelity': ipp_attribute_fidelity,
+                'document_name': document_name,
+                'compression': compression,
+                'document_format': document_format,
+                'document_natural_language': document_natural_language,
+                'job_k_octets': job_k_octets,
+                'job_impressions': job_impressions,
+                'job_media_sheets': job_media_sheets}},
               'auth_info': auth_info,
               'job_billing': job_billing,
               'job_sheets': job_sheets,
@@ -251,6 +269,15 @@ class IPPToolWrapper(object):
     @pyipptool_coroutine
     def print_job(self, uri,
                   printer_uri=None,
+                  job_name=colander.null,
+                  ipp_attribute_fidelity=colander.null,
+                  document_name=colander.null,
+                  compression=colander.null,
+                  document_format=colander.null,
+                  document_natural_language=colander.null,
+                  job_k_octets=colander.null,
+                  job_impressions=colander.null,
+                  job_media_sheets=colander.null,
                   auth_info=colander.null,
                   job_billing=colander.null,
                   job_sheets=colander.null,
@@ -259,7 +286,16 @@ class IPPToolWrapper(object):
         filename, delete = _get_filename_for_content(document_content)
         kw = {'header':
               {'operation_attributes':
-               {'printer_uri': printer_uri}},
+               {'printer_uri': printer_uri,
+                'job_name': job_name,
+                'ipp_attribute_fidelity': ipp_attribute_fidelity,
+                'document_name': document_name,
+                'compression': compression,
+                'document_format': document_format,
+                'document_natural_language': document_natural_language,
+                'job_k_octets': job_k_octets,
+                'job_impressions': job_impressions,
+                'job_media_sheets': job_media_sheets}},
               'auth_info': auth_info,
               'job_billing': job_billing,
               'job_sheets': job_sheets,
